==> http_client_log-1.0.0.tar.gz: http_client_log/src/HttpClientLogEntityPermissions.php <==
<?php

namespace Drupal\http_client_log;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\http_client_log\Entity\HttpClientLogEntity;


/**
 * Provides dynamic permissions for Http client log entity of different types.
 *
 * @ingroup http_client_log
 *
 */
class HttpClientLogEntityPermissions{

  use StringTranslationTrait;

  /**
   * Returns an array of node type permissions.
   *
   * @return array
   *   The HttpClientLogEntity by bundle permissions.
   *   @see \Drupal\user\PermissionHandlerInterface::getPermissions()
   */
  public function generatePermissions() {
    $perms = [];

    foreach (HttpClientLogEntity::loadMultiple() as $type) {
      $perms += $this->buildPermissions($type);
    }

    return $perms;
  }

  /**
   * Returns a list of node permissions for a given node type.
   *
   * @param \Drupal\http_client_log\Entity\HttpClientLogEntity $type
   *   The HttpClientLogEntity type.
   *
   * @return array
   *   An associative array of permission names and descriptions.
   */
  protected function buildPermissions(HttpClientLogEntity $type) {
    $type_id = $type->id();
    $type_params = ['%type_name' => $type->label()];

    return [
      "$type_id create entities" => [
        'title' => $this->t('Create new %type_name entities', $type_params),
      ],
      "$type_id edit own entities" => [
        'title' => $this->t('Edit own %type_name entities', $type_params),
      ],
      "$type_id edit any entities" => [
        'title' => $this->t('Edit any %type_name entities', $type_params),
      ],
      "$type_id delete own entities" => [
        'title' => $this->t('Delete own %type_name entities', $type_params),
      ],
      "$type_id delete any entities" => [
        'title' => $this->t('Delete any %type_name entities', $type_params),
      ],
    ];
  }

}

==> http_client_log-1.0.7.tar.gz: http_client_log/src/HttpClientLogEntityPermissions.php <==
<?php

namespace Drupal\http_client_log;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\http_client_log\Entity\HttpClientLogEntityType;


/**
 * Provides dynamic permissions for Http client log entity of different types.
 *
 * @ingroup http_client_log
 *
 */
class HttpClientLogEntityPermissions{

  use StringTranslationTrait;

  /**
   * Returns an array of node type permissions.
   *
   * @return array
   *   The HttpClientLogEntity by bundle permissions.
   *   @see \Drupal\user\PermissionHandlerInterface::getPermissions()
   */
  public function generatePermissions() {
    $perms = [];

    foreach (HttpClientLogEntityType::loadMultiple() as $type) {
      $perms += $this->buildPermissions($type);
    }

    return $perms;
  }

  /**
   * Returns a list of node permissions for a given node type.
   *
   * @param \Drupal\http_client_log\Entity\HttpClientLogEntity $type
   *   The HttpClientLogEntity type.
   *
   * @return array
   *   An associative array of permission names and descriptions.
   */
  protected function buildPermissions(HttpClientLogEntityType $type) {
    $type_id = $type->id();
    $type_params = ['%type_name' => $type->label()];

    return [
      "$type_id create entities" => [
        'title' => $this->t('Create new %type_name entities', $type_params),
      ],
      "$type_id edit own entities" => [
        'title' => $this->t('Edit own %type_name entities', $type_params),
      ],
      "$type_id edit any entities" => [
        'title' => $this->t('Edit any %type_name entities', $type_params),
      ],
      "$type_id delete own entities" => [
        'title' => $this->t('Delete own %type_name entities', $type_params),
      ],
      "$type_id delete any entities" => [
        'title' => $this->t('Delete any %type_name entities', $type_params),
      ],
    ];
  }

}
